@@ -35,7 +35,7 @@ Specifies the device name to suppress during instance launch.
 =cut
 
 has 'device_name'	=> ( is => 'ro', isa => 'Str', required => 1 );
-has 'ebs'			=> ( is => 'ro', isa => 'Maybe[Net::Amazon::EC2::EbsBlockDevice]', required => 0 );
+has 'ebs'			=> ( is => 'ro', isa => 'Maybe[Net::Amazon::EC2::EbsBlockDevice]|Maybe[Net::Amazon::EC2::EbsInstanceBlockDeviceMapping]', required => 0 );
 has 'virtual_name'	=> ( is => 'ro', isa => 'Maybe[Str]', required => 0 );
 has 'no_device'		=> ( is => 'ro', isa => 'Maybe[Int]', required => 0 );
 
